##
##  screen.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         screen
Summary:      Virtual Screen Manager
URL:          http://www.gnu.org/software/screen/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Terminal
License:      GPL
Version:      5.0.0
Release:      20240829

#   list of sources
Source0:      http://ftp.gnu.org/gnu/screen/screen-%{version}.tar.gz
Source1:      screen-multiuser.sh
Source2:      screen-multiuser.1

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, texinfo
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses
PreReq:       ncurses

%description
    Screen is a full-screen window manager that multiplexes a physical
    terminal between several processes (typically interactive shells).
    Each virtual terminal provides the functions of a DEC VT100 terminal
    and, in addition, several control functions from the ISO 6492 (ECMA
    48, ANSI X3.64) and ISO 2022 standards (e.g. insert/delete line and
    support for multiple character sets). There is a scroll-back history
    buffer for each virtual terminal and a copy-and-paste mechanism that
    allows moving text regions between windows.

%track
    prog screen = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/screen/
        regex     = screen-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} %{l_cppflags ncurses}" \
    LDFLAGS="%{l_ldflags ncurses}" \
    LIBS="-lncurses" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --with-sys-screenrc=%{l_prefix}/etc/screen/screenrc \
        --enable-colors256 \
        --disable-socket-dir

    #   build package
    %{l_make} %{l_mflags -O}

%install

    #   install package
    %{l_shtool} subst \
        -e 's;-chown root;-true;' \
        Makefile
    %{l_make} %{l_mflags} install \
        DESTDIR=$RPM_BUILD_ROOT

    #   strip down installation
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/screen
    mv $RPM_BUILD_ROOT%{l_prefix}/bin/screen-%{version} \
       $RPM_BUILD_ROOT%{l_prefix}/bin/screen
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/screen
    %{l_shtool} install -c -m 644 \
        -e 's;^#\(startup_message.off\);\1;' \
        etc/etcscreenrc \
        $RPM_BUILD_ROOT%{l_prefix}/etc/screen/screenrc

    #   install screen-multiuser(1) utility
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE screen-multiuser.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/bin/screen-multiuser
    %{l_shtool} install -c -m 644 \
        %{SOURCE screen-multiuser.1} \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(4755,%{l_susr},%{l_mgrp}) %{l_prefix}/bin/screen' \
        '%config %{l_prefix}/etc/screen/screenrc'

%files -f files

%clean

